==> fibonacci-heap-2.0.1.tgz: package/README.md <==
:scissors: [@heap-data-structure/fibonacci-heap](https://heap-data-structure.github.io/fibonacci-heap)
==

Fibonacci heap data structure for JavaScript.
See [docs](https://heap-data-structure.github.io/fibonacci-heap/index.html).
Parent is [@heap-data-structure/about](https://github.com/heap-data-structure/about).

> :warning: The code requires `regeneratorRuntime` to be defined, for instance by importing
> [regenerator-runtime/runtime](https://www.npmjs.com/package/regenerator-runtime).

```js
import {FibonacciHeap} from '@heap-data-structure/fibonacci-heap';
import {increasing} from '@heap-data-structure/js-compare';
let heap = new FibonacciHeap( increasing ) ;
```

[![License](https://img.shields.io/github/license/heap-data-structure/fibonacci-heap.svg)](https://raw.githubusercontent.com/heap-data-structure/fibonacci-heap/main/LICENSE)
[![Version](https://img.shields.io/npm/v/@heap-data-structure/fibonacci-heap.svg)](https://www.npmjs.org/package/@heap-data-structure/fibonacci-heap)
[![Tests](https://img.shields.io/github/workflow/status/heap-data-structure/fibonacci-heap/ci:test?event=push&label=tests)](https://github.com/heap-data-structure/fibonacci-heap/actions/workflows/ci:test.yml?query=branch:main)
[![Dependencies](https://img.shields.io/david/heap-data-structure/fibonacci-heap.svg)](https://david-dm.org/heap-data-structure/fibonacci-heap)
[![Dev dependencies](https://img.shields.io/david/dev/heap-data-structure/fibonacci-heap.svg)](https://david-dm.org/heap-data-structure/fibonacci-heap?type=dev)
[![GitHub issues](https://img.shields.io/github/issues/heap-data-structure/fibonacci-heap.svg)](https://github.com/heap-data-structure/fibonacci-heap/issues)
[![Downloads](https://img.shields.io/npm/dm/@heap-data-structure/fibonacci-heap.svg)](https://www.npmjs.org/package/@heap-data-structure/fibonacci-heap)

[![Code issues](https://img.shields.io/codeclimate/issues/heap-data-structure/fibonacci-heap.svg)](https://codeclimate.com/github/heap-data-structure/fibonacci-heap/issues)
[![Code maintainability](https://img.shields.io/codeclimate/maintainability/heap-data-structure/fibonacci-heap.svg)](https://codeclimate.com/github/heap-data-structure/fibonacci-heap/trends/churn)
[![Code coverage (cov)](https://img.shields.io/codecov/c/gh/heap-data-structure/fibonacci-heap/main.svg)](https://codecov.io/gh/heap-data-structure/fibonacci-heap)
[![Code technical debt](https://img.shields.io/codeclimate/tech-debt/heap-data-structure/fibonacci-heap.svg)](https://codeclimate.com/github/heap-data-structure/fibonacci-heap/trends/technical_debt)
[![Documentation](https://heap-data-structure.github.io/fibonacci-heap/badge.svg)](https://heap-data-structure.github.io/fibonacci-heap/source.html)
[![Package size](https://img.shields.io/bundlephobia/minzip/@heap-data-structure/fibonacci-heap)](https://bundlephobia.com/result?p=@heap-data-structure/fibonacci-heap)


## :scroll: References

  - [Wikipedia Article on Fibonacci Heaps](https://en.wikipedia.org/wiki/Fibonacci_heap)
  - [Introduction to Algorithms Chapter 19](https://en.wikipedia.org/wiki/Introduction_to_Algorithms)

==> fibonacci-heap-2.0.2.tgz: package/README.md <==
:scissors: [@heap-data-structure/fibonacci-heap](https://heap-data-structure.github.io/fibonacci-heap)
==

Fibonacci heap data structure for JavaScript.
See [docs](https://heap-data-structure.github.io/fibonacci-heap/index.html).
Parent is [@heap-data-structure/about](https://github.com/heap-data-structure/about).

> :warning: The code requires `regeneratorRuntime` to be defined, for instance by importing
> [regenerator-runtime/runtime](https://www.npmjs.com/package/regenerator-runtime).

```js
import {FibonacciHeap} from '@heap-data-structure/fibonacci-heap';
import {increasing} from '@aureooms/js-compare';
let heap = new FibonacciHeap( increasing ) ;
```

[![License](https://img.shields.io/github/license/heap-data-structure/fibonacci-heap.svg)](https://raw.githubusercontent.com/heap-data-structure/fibonacci-heap/main/LICENSE)
[![Version](https://img.shields.io/npm/v/@heap-data-structure/fibonacci-heap.svg)](https://www.npmjs.org/package/@heap-data-structure/fibonacci-heap)
[![Tests](https://img.shields.io/github/workflow/status/heap-data-structure/fibonacci-heap/ci:test?event=push&label=tests)](https://github.com/heap-data-structure/fibonacci-heap/actions/workflows/ci:test.yml?query=branch:main)
[![Dependencies](https://img.shields.io/david/heap-data-structure/fibonacci-heap.svg)](https://david-dm.org/heap-data-structure/fibonacci-heap)
[![Dev dependencies](https://img.shields.io/david/dev/heap-data-structure/fibonacci-heap.svg)](https://david-dm.org/heap-data-structure/fibonacci-heap?type=dev)
[![GitHub issues](https://img.shields.io/github/issues/heap-data-structure/fibonacci-heap.svg)](https://github.com/heap-data-structure/fibonacci-heap/issues)
[![Downloads](https://img.shields.io/npm/dm/@heap-data-structure/fibonacci-heap.svg)](https://www.npmjs.org/package/@heap-data-structure/fibonacci-heap)

[![Code issues](https://img.shields.io/codeclimate/issues/heap-data-structure/fibonacci-heap.svg)](https://codeclimate.com/github/heap-data-structure/fibonacci-heap/issues)
[![Code maintainability](https://img.shields.io/codeclimate/maintainability/heap-data-structure/fibonacci-heap.svg)](https://codeclimate.com/github/heap-data-structure/fibonacci-heap/trends/churn)
[![Code coverage (cov)](https://img.shields.io/codecov/c/gh/heap-data-structure/fibonacci-heap/main.svg)](https://codecov.io/gh/heap-data-structure/fibonacci-heap)
[![Code technical debt](https://img.shields.io/codeclimate/tech-debt/heap-data-structure/fibonacci-heap.svg)](https://codeclimate.com/github/heap-data-structure/fibonacci-heap/trends/technical_debt)
[![Documentation](https://heap-data-structure.github.io/fibonacci-heap/badge.svg)](https://heap-data-structure.github.io/fibonacci-heap/source.html)
[![Package size](https://img.shields.io/bundlephobia/minzip/@heap-data-structure/fibonacci-heap)](https://bundlephobia.com/result?p=@heap-data-structure/fibonacci-heap)


## :scroll: References

  - [Wikipedia Article on Fibonacci Heaps](https://en.wikipedia.org/wiki/Fibonacci_heap)
  - [Introduction to Algorithms Chapter 19](https://en.wikipedia.org/wiki/Introduction_to_Algorithms)
